driver

package
v0.0.0-...-95eea6f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 6, 2026 License: UPL-1.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetConnectionInstantiator

func GetConnectionInstantiator(config *common.OracleDriverConfig, ns *session.NetworkSession) (common.ConnectionInstantiator, error)

GetConnectionInstantiator returns the correct connection instantiator according to the configuration

Types

This section is empty.

Directories

Path Synopsis
Package logging package to define common logging usage in the Oracle driver
Package logging package to define common logging usage in the Oracle driver
network
ttc

Jump to